<?php
add_action('after_setup_theme', 'friday_news_lite_after_setup_theme');

function friday_news_lite_after_setup_theme() {
    global $content_width;
    $content_width = 790;
    
    add_editor_style();

    add_theme_support('html5');
    add_theme_support('title-tag');    
    add_theme_support('post-thumbnails');
    add_theme_support('loop-pagination');
    add_theme_support('automatic-feed-links');
    add_theme_support('post-formats', array('image', 'gallery', 'audio', 'video', 'quote'));

    register_nav_menus(array(
        'main-nav'   => esc_html__('Main Menu', 'friday-news-lite')
        ));

    if (is_admin()) {        
        add_action('in_widget_form', 'friday_news_lite_add_widget_field_sub_title', 5, 3);
        add_filter('widget_update_callback', 'friday_news_lite_add_widget_field_sub_title_update', 5, 3);
        add_action( 'admin_enqueue_scripts', 'friday_news_lite_add_custom_admin_css' );

    }else{
        add_action('wp_enqueue_scripts', 'friday_news_lite_enqueue_scripts');
        add_filter('body_class', 'friday_news_lite_set_body_class');        
        add_filter('friday_news_lite_get_sidebar', 'friday_news_lite_set_sidebar', 10, 2);
        add_filter('friday_news_lite_get_header', 'friday_news_lite_set_header', 20); 
        add_filter('excerpt_length', 'friday_news_lite_custom_excerpt_length', 999);
        add_filter('friday_news_lite_set_body_class', 'friday_news_lite_set_page_body_class');
    }

    add_image_size( 'friday_news-widget-85x72', 85, 72, true );
    add_image_size( 'friday_news-widget-345x220', 345, 220, true );
    add_image_size( 'friday_news-widget-blog3-730x438', 730, 438, true );
    add_image_size( 'friday_news-blog1-455x290', 455, 290, true );
    add_image_size( 'friday_news-blog2-380x242', 380, 242, true );
    add_image_size( 'friday_news-blog4-244x170', 244, 170, true );
    add_image_size( 'friday_news-related-posts-350x230', 350, 230, true );
    add_image_size( 'friday_news-single-gallery-730x375', 730, 375, true );
    add_image_size( 'friday_news-single-featured-1140x540', 1140, 540, true );

    load_theme_textdomain('friday-news-lite', get_template_directory() . '/languages');
}

function friday_news_lite_add_custom_admin_css(){
    wp_register_style( 'friday_news-custom-admin-css', get_template_directory_uri() . '/css/custom-admin.css', false, '1.0.0' );
    wp_enqueue_style( 'friday_news-custom-admin-css' );
}

function friday_news_lite_enqueue_scripts(){
    global $wp_styles, $is_IE;
    $dir = get_template_directory_uri();

    wp_enqueue_style('friday-news-lite-fonts', friday_news_lite_fonts_url(), array(), null );
    wp_enqueue_style('bootstrap', $dir . "/css/bootstrap.css", array(), NULL);
    wp_enqueue_style('font-awesome-min', $dir . "/css/font-awesome.min.css", array(), NULL);
    wp_enqueue_style('owl-carousel', $dir . "/css/owl.carousel.css", array(), NULL);
    wp_enqueue_style('owl-transitions', $dir . "/css/owl.transitions.css", array(), NULL);
    wp_enqueue_style('owl-theme', $dir . "/css/owl.theme.css", array(), NULL);
    wp_enqueue_style('sb-search', $dir . "/css/sb-search.css", array(), NULL);
    wp_enqueue_style('friday-news-lite-style', get_stylesheet_uri(), array(), NULL);
      
    if (is_singular())
        wp_enqueue_script('comment-reply');

    if ($is_IE) {
        wp_register_style('friday-news-lite-ie', "{$dir}/css/ie/ie.css", array(), NULL);
        wp_enqueue_style('friday-news-lite-ie');
        $wp_styles->add_data('friday-news-lite-ie', 'conditional', 'lt IE 9');

        wp_register_style('friday-news-lite-ie9', "{$dir}/css/ie/ie9.css", array(), NULL);
        wp_enqueue_style('friday-news-lite-ie9');
        $wp_styles->add_data('friday-news-lite-ie9', 'conditional', 'IE 9');
    }

    /* JAVASCRIPTS */
    wp_enqueue_script('friday-news-lite-javascript-modernizr-custom-min', $dir . '/js/javascript.modernizr.custom.min.js', array('jquery'), null);
    wp_enqueue_script('jquery-bootstrap-min', $dir . '/js/jquery.bootstrap.min.js', array('jquery'), null, true);
    wp_enqueue_script('friday-news-lite-custom', $dir . '/js/custom.js', array('jquery'), null, true);
    
    /* SEND LOCALIZATION TO FRONTEND */
    wp_localize_script('friday-news-lite-custom', 'friday_news_lite_variable', friday_news_lite_custom_front_localization());
}

function friday_news_lite_fonts_url() {
    $fonts_url = '';
    $fonts     = array();
    $subsets   = 'latin,latin-ext';

    /*
     * Translators: If there are characters in your language that are not supported
     * by Playfair Display, translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Playfair Display font: on or off', 'friday-news-lite' ) ) {
        $fonts[] = 'Playfair Display:400,700,400italic';
    }

    /*
     * Translators: If there are characters in your language that are not supported
     * by Raleway, translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Raleway font: on or off', 'friday-news-lite' ) ) {
        $fonts[] = 'Raleway:100,300,400,600,700,800';
    }

    /*
     * Translators: If there are characters in your language that are not supported
     * by Open Sans, translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Open Sans font: on or off', 'friday-news-lite' ) ) {
        $fonts[] = 'Open Sans:700,600,800,400,300italic,300';
    }

    /*
     * Translators: To add an additional character subset specific to your language,
     * translate this to 'greek', 'cyrillic', 'devanagari' or 'vietnamese'. Do not translate into your own language.
     */
    $subset = _x( 'no-subset', 'Add new subset (greek, cyrillic, devanagari, vietnamese)', 'friday-news-lite' );

    if ( 'cyrillic' == $subset ) {
        $subsets .= ',cyrillic,cyrillic-ext';
    } elseif ( 'greek' == $subset ) {
        $subsets .= ',greek,greek-ext';
    } elseif ( 'devanagari' == $subset ) {
        $subsets .= ',devanagari';
    } elseif ( 'vietnamese' == $subset ) {
        $subsets .= ',vietnamese';
    }

    if ( $fonts ) {
        $fonts_url = add_query_arg( array(
            'family' => urlencode( implode( '|', $fonts ) ),
            'subset' => urlencode( $subsets ),
        ), 'https://fonts.googleapis.com/css' );
    }

    return $fonts_url;
}

function friday_news_lite_custom_front_localization() {
    $friday_news_lite_localization = array(
        'template' => array(
            'post_id' => (is_singular()) ? get_queried_object_id() : 0
        ),
        'url' => array(
            'template_directory_uri' => get_template_directory_uri().'/',
        ),
        'validate' => array(
            'form' => array(
                'submit'  => esc_html__('SEND', 'friday-news-lite'),
                'sending' => esc_html__('SENDING...', 'friday-news-lite')
            ),
            'name' => array(
                'required'  => esc_html__('Please enter your name.', 'friday-news-lite'),
                'minlength' => esc_html__('At least {0} characters required.', 'friday-news-lite'),
            ),
            'email' => array(
                'required' => esc_html__('Please enter your email.', 'friday-news-lite'),
                'email'    => esc_html__('Please enter a valid email.', 'friday-news-lite')
            ),
            'comment' => array(
                'required'  => esc_html__('Please enter a comment.', 'friday-news-lite'),
                'minlength' => esc_html__('At least {0} characters required.', 'friday-news-lite'),
            ),
            'message' => array(
                'required'  => esc_html__('Please enter a message.', 'friday-news-lite'),
                'minlength' => esc_html__('At least {0} characters required.', 'friday-news-lite'),
            ),
            'subject' => array(
                'required'  => esc_html__('Please enter a subject.', 'friday-news-lite'),
                'minlength' => esc_html__('At least {0} characters required.', 'friday-news-lite'),
            )
        ),
        'ajax' => array(
            'url'      => admin_url('admin-ajax.php'),
            'loading' => esc_html__('Loading...', 'friday-news-lite'),
            'loadmore' => esc_html__('Load more', 'friday-news-lite'),
        )
    );

    return $friday_news_lite_localization;
}

function friday_news_lite_set_body_class($classes){
    
    if($friday_news_lite_current_layout = friday_news_lite_get_template_setting()){
        switch ($friday_news_lite_current_layout['layout_id']) {
            case 'one-post-in-row':
            case 'two-posts-in-row':
            case 'three-posts-in-row':
                array_push($classes, 'kopa-sub-page');
                break;
            case 'single-2':
                array_push($classes, 'kopa-single-2');
                break;
            case 'single-3':
                array_push($classes, 'kopa-single-3');
                break;
            case 'full-width':
                array_push($classes,  'kopa-sub-page kopa-full-width');
                break;  
            case 'error-404':
                array_push($classes,  'kopa-sub-page kopa-full-width page-404');
                break;  
        }
    }else{
        if(is_404()){
            array_push($classes,  'kopa-sub-page kopa-full-width page-404');
        }
    }
    if( get_theme_mod( 'sticky_menu', 'enable' ) == 'enable' ){
        array_push( $classes, 'has-sticky-menu');
    }
    
    return apply_filters('friday_news_lite_set_body_class', $classes);
}

function friday_news_lite_get_option( $option_name, $default = null ) {
    if(function_exists('kopa_get_option')){
        return kopa_get_option($option_name, $default);
    }    
    return $default;
}

function friday_news_lite_get_template_setting($default = null) {
    if(function_exists('kopa_get_template_setting')){
        return kopa_get_template_setting();
    }    

    return $default;
}

function friday_news_lite_get_first_cat( $id_post = null, $class = null ){
    $category = get_the_category($id_post);
    if( $category ) {
        return '<a href="'.esc_url(get_category_link( $category[0]->term_id )).'" class="'.$class.'">'.wp_kses_post( $category[0]->cat_name ).'</a>';
    }
}

function friday_news_lite_get_url_embed_string($content,$format) {
    // find all urls
    preg_match_all('/(http|https)\:\/\/[a-zA-Z0-9\-\.]+\.[a-zA-Z]{2,3}(\/\S*)?/', $content, $links);

    foreach ($links[0] as $link) {
        if($format == 'video') {
            if( preg_match('~youtube\.com|vimeo\.com~', $link)){
                return $link;
                break;
            }  
        }

        if($format == 'audio') {
            if( preg_match('~soundcloud\.com~', $link)){
                return $link;
                break;
            }  
        }
    }
}

function friday_news_lite_get_icon_by_post_format(){
    $post_format = get_post_format();
    if($post_format == 'gallery'){
        $icon = '<i class="fa fa-image"></i>';
    }elseif($post_format == 'audio'){
        $icon = '<i class="fa fa-music"></i>';
    }elseif($post_format == 'video'){
        $icon = '<i class="fa fa-play"></i>';
    }elseif($post_format == 'image'){
        $icon = '<i class="fa fa-camera"></i>';
    }elseif($post_format == 'quote'){
        $icon = '<i class="fa fa-quote-right"></i>';
    }else{
        $icon = '<i class="fa fa-file-o"></i>';
    }
    return $icon;
}

function friday_news_lite_custom_excerpt_length($length){
    if( is_archive() || is_search() || is_category() || is_front_page() ) {
        $length = (int) get_theme_mod('custom_excerpt_lenght', 55 );
    }
    return $length;
}

function friday_news_lite_set_header($value){
    $value = get_theme_mod( 'header_style' );
    return $value;
}

function friday_news_lite_set_page_body_class($classes){
    $header_style = get_theme_mod('header_style');

    if($header_style == 'home-1'){
        array_push($classes, 'kopa-home-page', 'has-sticky-menu');
    }elseif($header_style == 'home-2'){
        array_push($classes, 'kopa-home-page', 'has-sticky-menu', 'kopa-home-page-2');
    }elseif($header_style == 'home-3'){
        array_push($classes, 'kopa-home-page', 'kopa-home-page-2', 'header-style-3', 'has-sticky-menu');
    }elseif($header_style == 'home-4'){
        array_push($classes, 'kopa-home-page', 'has-sticky-menu', 'header-style-2');
    }

    return $classes;
}